@@ -1,6 +1,5 @@
 import argparse
-import _internal
-
+from . import _internal
 
 def config():
     parser = argparse.ArgumentParser(description='Pytest Report Portal Wrapper')
@@ -9,14 +8,16 @@ def config():
     parser.add_argument('--bearer-uuid', '-u', required=True, help='Auth bearer UUID')
     parser.add_argument('--project-name', '-p', required=True, help='Report Portal project name')
     args = parser.parse_args()
+    print(args.bearer_uuid)
+    _internal.Data.endpoint = args.host
+    _internal.Data.launch_name = args.launch_name 
+    _internal.Data.uuid = args.bearer_uuid
+    _internal.Data.project = args.project_name
+    _internal.Data.update_url()
+    _internal.Launch.update_headers()
 
-    _internal.HOST = args.host
-    _internal.LAUNCH_NAME = args.launch_name
-    _internal.UUID = args.bearer_id
-    _internal.PROJECT = args.project_name
-
-
+    
 if __name__ == '__main__':
-    config()
-    _internal.start_launch()
+    data = config()
+    _internal.Launch.start_launch()
     
