@@ -1,68 +1,10 @@
-from time import time
 import requests
 import inspect
-import json
-
-
-def timestamp():
-    return str(int(time() * 1000))
-
-
-class Data:
-    endpoint = ''
-    launch_name = ''
-    uuid = ''
-    project = ''
-
-    @classmethod
-    def update_url(cls):
-        cls.endpoint = f'{cls.endpoint}/api/v1/{cls.project}'
-        Launch.update_headers()
-
-    @classmethod
-    def parse(cls):
-        import configparser
-        import os
-
-        filename = 'report_properties.ini'
-        for root, dirs, files in os.walk('.'):
-            if filename in files:
-                # The file was found
-                filepath = os.path.join(root, filename)
-        # The root directory of the project is the parent directory of the directory containing 'requirements.txt'
-        config = configparser.ConfigParser()
-        config.read(filepath)
-
-        endpoint = config.get('Data', 'endpoint')
-        uuid = config.get('Data', 'uuid')
-        launch_name = config.get('Data', 'launch_name')
-        project = config.get('Data', 'project')
-
-        Data.endpoint = endpoint
-        Data.uuid = uuid
-        Data.launch_name = launch_name 
-        Data.project = project
-        Data.update_url()
+from ._data import timestamp, Data, parse
 
 class Launch:
-    headers = {
-        'Authorization': f'Bearer {Data.uuid}'
-    }
-
-    base_item_data = {
-       'name': 'My Test Suite',
-       'type': 'suite',
-       'start_time': timestamp(),
-       'launchUuid': ''
-    }
-
     items = {'': ''}
 
-    @classmethod
-    def update_headers(cls):
-        cls.headers = {
-            'Authorization': f'Bearer {Data.uuid}'}
-
     @classmethod
     def get_enclosing_class_name(cls, func):
         '''
@@ -77,13 +19,13 @@ class Launch:
                 return func.__qualname__.split('.')[0]
         return None
 
-    
+
     @classmethod
     def get_caller_name(cls):
         frame = inspect.currentframe()
         caller_frame = frame.f_back.f_back
         return caller_frame.f_code.co_name
-    
+
     @classmethod
     def start_launch(cls):
 
@@ -92,38 +34,40 @@ class Launch:
             'description': 'My first launch on RP',
             f'startTime': timestamp()}
 
-        if cls.base_item_data['launchUuid'] == '':
-            respone = requests.post(url=f'{Data.endpoint}/launch', headers=cls.headers, json=data)
+        if Data.base_item_data['launchUuid'] == '':
+            respone = requests.post(url=f'{Data.endpoint}/launch', headers=Data.headers, json=data)
             print(respone.json())
             launch_uuid = respone.json()['id']
-            cls.base_item_data['launchUuid'] = launch_uuid
+            Data.base_item_data['launchUuid'] = launch_uuid
 
         else:
             print('Second attemp to start a launch')
-    
+
     @classmethod
     def finish_launch(cls):
-        requests.put(url=f'{Data.endpoint}/launch/{cls.base_item_data["launchUuid"]}/finish', headers=cls.headers, json={'endTime': timestamp()})
+        requests.put(url=f'{Data.endpoint}/launch/{Data.base_item_data["launchUuid"]}/finish', headers=Data.headers, json={'endTime': timestamp()})
+
 
-    
     @classmethod
     def create_report_item(
             cls,
             name: str,
-            parent_item: str = '', 
-            type: str = '',  
-            description: str = '', 
+            parent_item: str = '',
+            type: str = '',
+            description: str = '',
             has_stats: bool = True):
 
+        parse()
+        print(Data.endpoint)
         parent = cls.items[parent_item]
-        data = cls.base_item_data
+        data = Data.base_item_data
         data['name'] = name
         data['type'] = type
         data['start_time'] = timestamp()
         data['description'] = description
         data['hasStats'] = has_stats
 
-        response = requests.post(url=f'{Data.endpoint}/item/{parent}', headers=cls.headers, json=data)
+        response = requests.post(url=f'{Data.endpoint}/item/{parent}', headers=Data.headers, json=data)
         response_json = response.json()
         return response_json['id']
 
@@ -131,51 +75,51 @@ class Launch:
     def finish_item(cls, item_name: str):
         item = cls.items[item_name]
         json_data= {
-            'launchUuid': cls.base_item_data['launchUuid'],
-            'endTime': timestamp()
-        }
-        requests.put(url=f'{Data.endpoint}/item/{item}', headers=cls.headers, json=json_data)
-    
+            'launchUuid': Data.base_item_data['launchUuid'],
+            'endTime': timestamp()}
+        
+        requests.put(url=f'{Data.endpoint}/item/{item}', headers=Data.headers, json=json_data)
+
     @classmethod
     def finish_passed_item(cls, item_name: str):
         item = cls.items[item_name]
         json_data= {
-            'launchUuid': cls.base_item_data['launchUuid'],
+            'launchUuid': Data.base_item_data['launchUuid'],
             'endTime': timestamp(),
             'status': 'passed'
         }
-        requests.put(url=f'{Data.endpoint}/item/{item}', headers=cls.headers, json=json_data)
-    
+        requests.put(url=f'{Data.endpoint}/item/{item}', headers=Data.headers, json=json_data)
+
     @classmethod
     def finish_failed_item(cls, item_name: str, reason):
         item = cls.items[item_name]
         json_data = {
-            'launchUuid': cls.base_item_data['launchUuid'],
+            'launchUuid': Data.base_item_data['launchUuid'],
             'endTime': timestamp(),
             'status': 'failed',
             'issue': {'comment': reason}
             }
 
-        requests.put(url=f'{Data.endpoint}/item/{item}', headers=cls.headers, json=json_data)
-    
+        requests.put(url=f'{Data.endpoint}/item/{item}', headers=Data.headers, json=json_data)
+
     @classmethod
     def create_log(cls, item: str, message: str, level: str = "INFO"):
         json_data = {
-            "launchUuid": cls.base_item_data['launchUuid'],
+            "launchUuid": Data.base_item_data['launchUuid'],
             "itemUuid": cls.items[item],
             "time": timestamp(),
             "message": message,
             "level": level,
-        }   
+        }
 
-        response = requests.post(url=f'{Data.endpoint}/log', headers=cls.headers, json=json_data)
+        response = requests.post(url=f'{Data.endpoint}/log', headers=Data.headers, json=json_data)
 
     # @classmethod
     # def add_attachment(cls, name: str, item: str, file_path: str):
     #     import os
     #     file_name = os.path.basename(file_path)
     #     body = {
-    #         "launchUuid": cls.base_item_data['launchUuid'],
+    #         "launchUuid": Data.base_item_data['launchUuid'],
     #         "itemUuid": cls.items[item],
     #         "time": timestamp(),
     #         "message": cls.items[item],
@@ -188,11 +132,11 @@ class Launch:
     #     json_file_path = '/tmp/json_file.json'
     #     with open(json_file_path, 'w') as file:
     #         file.write(json.dumps([body]))
-        
+
     #     payload = {"json_request_part": f'{json.dumps([body])};type=application/json'}
     #     print(payload)
     #     files = {'file': (file_name ,open(file_path,'rb'), 'image/png')}
-        
+
     #     data = f"json_request_part='{json.dumps([body])};type=application/json'"
 
     #     files = {
@@ -200,12 +144,12 @@ class Launch:
     #         ('json_request_part', open(json_file_path, 'r'), 'application/json')
     #     }
 
-    #     response = requests.post(url=f'{Data.endpoint}/log', headers=cls.headers, data=files)
+    #     response = requests.post(url=f'{Data.endpoint}/log', headers=Data.headers, data=files)
     #     print(response.json())
 
     # def add_attachment(cls, item: str, file_path: str):
     #     json_data = {
-    #         "launchUuid": cls.base_item_data['launchUuid'],
+    #         "launchUuid": Data.base_item_data['launchUuid'],
     #         "itemUuid": cls.items[item],
     #         "time": timestamp(),
     #         "message": cls.items[item],
@@ -214,7 +158,7 @@ class Launch:
 
     #     with open(file_path, 'r') as f:
     #         file_data = f.read()
-        
+
     #     # Construct the multipart/form-data request
     #     data = (
     #         '--' + '---------------------------1234567890' + '\r\n' +
@@ -229,9 +173,11 @@ class Launch:
     #     )
 
     #     # Send the API request
-    #     headers = cls.headers
+    #     headers = Data.headers
     #     headers['Content-Type'] = 'multipart/form-data; boundary=---------------------------1234567890'
     #     response = requests.post(url=f'{Data.endpoint}/log', headers=headers, data=data)
 
     #     print(response.status_code)
-    #     print(response.text)
\ No newline at end of file
+    #     print(response.text)
+
+
