@@ -1,20 +1,21 @@
 import pytest
+from ._internal import Launch, Data, parse
+
 
 def pytest_addoption(parser):
     parser.addoption("--report", action="store", default=None,
                      help="path to the script to be executed before running tests")
 
 def pytest_sessionstart(session):
-    from _internal import Launch, Data
-
     script_path = session.config.getoption("--report")
     if script_path:
-        Data.parse()
+        parse()
         Launch.start_launch()
 
 def pytest_sessionfinish(session, exitstatus):
-    from _internal import Launch
-
     script_path = session.config.getoption("--report")
     if script_path:
-        Launch.finish_launch()
\ No newline at end of file
+        Launch.finish_launch()
+
+def parsepytest_load_initial_conftests_data(args):
+        parse()
