@@ -5,17 +5,28 @@ import asyncio
 
 
 def _run_func(func, *args, **kwargs):
+    __tracebackhide__ = True
     if inspect.iscoroutinefunction(func):
-        loop = asyncio.get_event_loop()
-        return loop.run_until_complete(func(*args, **kwargs))
+        try:
+            loop = asyncio.get_running_loop()
+        except RuntimeError as e:
+            if "no running event loop" in str(e):
+                loop = asyncio.new_event_loop()
+                asyncio.set_event_loop(loop)
+            else:
+                raise e
+
+            return loop.run_until_complete(func(*args, **kwargs))
 
     return func(*args, **kwargs)
 
-def step(name: str):
+def step(title: str):
     def decorator(func):
         @functools.wraps(func)
         def wrapper(*args, **kwargs):
+            __tracebackhide__ = True
             parent = Launch.get_caller_name()
+            name = title.format(*args, **kwargs)
             item_id = Launch.create_report_item(
                 name=name,
                 parent_item=parent,
@@ -38,10 +49,12 @@ def step(name: str):
         return wrapper
     return decorator
 
-def title(name: str):
+def title(title: str):
     def decorator(func):
         @functools.wraps(func)
         def wrapper(*args, **kwargs):
+            # __tracebackhide__ = True
+            name = title.format(*args, **kwargs)
             item_id = Launch.create_report_item(
                 name=name,
                 parent_item=Launch.get_enclosing_class_name(func),
@@ -58,6 +71,7 @@ def title(name: str):
 
 def feature(name: str):
     def decorator(cls):
+        __tracebackhide__ = True
         item_id = Launch.create_report_item(
             name=name,
             type='suite',
@@ -70,7 +84,7 @@ def feature(name: str):
 
 def story(name: str):
     def decorator(cls):
-
+        __tracebackhide__ = True
         parent = cls.__mro__[1].__name__
         item_id = Launch.create_report_item(
             name=name,
@@ -83,4 +97,3 @@ def story(name: str):
 
     return decorator
 
-
